@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-document.c 5803 2007-08-15 00:08:37Z paolo $
+ * $Id: gedit-document.c 5854 2007-08-27 15:38:06Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -47,7 +47,7 @@
 #include "gedit-utils.h"
 #include "gedit-metadata-manager.h"
 #include "gedit-language-manager.h"
-#include "gedit-source-style-manager.h"
+#include "gedit-style-scheme-manager.h"
 #include "gedit-document-loader.h"
 #include "gedit-document-saver.h"
 #include "gedit-marshal.h"
@@ -559,11 +559,11 @@ set_language (GeditDocument     *doc,
 	gtk_source_buffer_set_language (GTK_SOURCE_BUFFER (doc), lang);
 
 	if (lang != NULL)
-		gtk_source_buffer_set_highlight (GTK_SOURCE_BUFFER (doc),
-						 gedit_prefs_manager_get_enable_syntax_highlighting ());
+		gtk_source_buffer_set_highlight_syntax (GTK_SOURCE_BUFFER (doc),
+				 gedit_prefs_manager_get_enable_syntax_highlighting ());
 	else
-		gtk_source_buffer_set_highlight (GTK_SOURCE_BUFFER (doc), 
-						 FALSE);
+		gtk_source_buffer_set_highlight_syntax (GTK_SOURCE_BUFFER (doc), 
+				 FALSE);
 
 	if (set_by_user && (doc->priv->uri != NULL))
 	{
@@ -606,19 +606,20 @@ set_encoding (GeditDocument       *doc,
 static GtkSourceStyleScheme *
 get_default_style_scheme (void)
 {
-	gchar                 *scheme_id;
-	GtkSourceStyleScheme  *def_style;
-	GtkSourceStyleManager *manager;
-	
-	manager = gedit_get_source_style_manager ();
+	gchar *scheme_id;
+	GtkSourceStyleScheme *def_style;
+	GtkSourceStyleSchemeManager *manager;
+
+	manager = gedit_get_style_scheme_manager ();
 	scheme_id = gedit_prefs_manager_get_source_style_scheme ();
-	def_style = gtk_source_style_manager_get_scheme (manager, scheme_id);
+	def_style = gtk_source_style_scheme_manager_get_scheme (manager,
+								scheme_id);
 
 	if (def_style == NULL)
 	{
 		g_warning ("Default style scheme '%s' cannot be found, falling back to 'classic' style scheme ", scheme_id);
-			
-		def_style = gtk_source_style_manager_get_scheme (manager, "classic");
+
+		def_style = gtk_source_style_scheme_manager_get_scheme (manager, "classic");
 		if (def_style == NULL) 
 		{
 			g_warning ("Style scheme 'classic' cannot be found, check your GtkSourceView installation.");			
@@ -632,7 +633,6 @@ get_default_style_scheme (void)
 static void
 gedit_document_init (GeditDocument *doc)
 {
-	GtkSourceStyleManager *style_manager;
 	GtkSourceStyleScheme *style_scheme;
 
 	gedit_debug (DEBUG_DOCUMENT);
@@ -663,14 +663,12 @@ gedit_document_init (GeditDocument *doc)
 	gtk_source_buffer_set_max_undo_levels (GTK_SOURCE_BUFFER (doc), 
 					       gedit_prefs_manager_get_undo_actions_limit ());
 
-	/* TODO: Set the bracket matching tag style -- Paolo (10 Jan. 2005) */
-	gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (doc), 
-					      gedit_prefs_manager_get_bracket_matching ());
+	gtk_source_buffer_set_highlight_matching_brackets (GTK_SOURCE_BUFFER (doc), 
+							   gedit_prefs_manager_get_bracket_matching ());
 
 	gedit_document_set_enable_search_highlighting (doc,
 						       gedit_prefs_manager_get_enable_search_highlighting ());
 
-	style_manager = gedit_get_source_style_manager ();
 	style_scheme = get_default_style_scheme ();
 	if (style_scheme != NULL)
 		gtk_source_buffer_set_style_scheme (GTK_SOURCE_BUFFER (doc),
@@ -772,7 +770,7 @@ set_uri (GeditDocument *doc,
 
 			if (strcmp (data, "_NORMAL_") != 0)
 			{
-				language = gtk_source_language_manager_get_language_by_id (
+				language = gtk_source_language_manager_get_language (
 							gedit_get_language_manager (),
 							data);
 			}
@@ -1663,7 +1661,7 @@ gedit_document_replace_all (GeditDocument       *doc,
 	gchar *replace_text;
 	gint replace_text_len;
 	GtkTextBuffer *buffer;
-	gboolean check_brackets;
+	gboolean brackets_highlighting;
 	gboolean search_highliting;
 
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), 0);
@@ -1697,8 +1695,8 @@ gedit_document_replace_all (GeditDocument       *doc,
 	doc->priv->stop_cursor_moved_emission = TRUE;
 
 	/* also avoid spending time matching brackets */
-	check_brackets = gtk_source_buffer_get_check_brackets (GTK_SOURCE_BUFFER (buffer));
-	gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (buffer), FALSE);
+	brackets_highlighting = gtk_source_buffer_get_highlight_matching_brackets (GTK_SOURCE_BUFFER (buffer));
+	gtk_source_buffer_set_highlight_matching_brackets (GTK_SOURCE_BUFFER (buffer), FALSE);
 
 	/* and do search highliting later */
 	search_highliting = gedit_document_get_enable_search_highlighting (doc);
@@ -1754,8 +1752,8 @@ gedit_document_replace_all (GeditDocument       *doc,
 	doc->priv->stop_cursor_moved_emission = FALSE;
 	emit_cursor_moved (doc);
 
-	gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (buffer),
-					      check_brackets);
+	gtk_source_buffer_set_highlight_matching_brackets (GTK_SOURCE_BUFFER (buffer),
+							   brackets_highlighting);
 	gedit_document_set_enable_search_highlighting (doc, search_highliting);
 
 	g_free (search_text);
